# -*- coding: utf-8 -*-

# mapWOC
#
# Description: Main entry point for the test suite.
#              Just run this file as a python script to execute all tests
#
# Copyright:
# Copyright (C) 2011 Bundesamt für Sicherheit in der Informationstechnik
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2,
# or, at your option, any later version as published by the Free
# Software Foundation
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-13

import os
import sys
import unittest
import optparse

test_dir = os.path.dirname(__file__)
sys.path.append(os.path.join(test_dir, os.pardir))

def find_test_modules(dirname, package = None):
    """
    Return a list the names of the test modules in the directory dirname

    The return value is a list of names that can be passed to
    unittest.defaultTestLoader.loadTestsFromNames.  Each name of the
    list is the name of a pure python module, one for each file in
    dirname whose name starts with 'test' and ends with '.py'.

    The optional parameter package should be the name of the python
    package whose directory is dirname.  If package is given all names
    in the returned list will be prefixed with package and a dot.
    """
    if package:
        prefix = package + "."
    else:
        prefix = ""

    suffix = ".py"
    return [prefix + name[:-len(suffix)]
            for name in os.listdir(dirname)
                if name.startswith("test") and name.endswith(suffix)]


def main():
    """Run all the tests in the test suite"""

    parser = optparse.OptionParser()
    parser.set_defaults(verbosity=1)
    parser.add_option("-v", "--verbose", action="store_const", const=2,
                      dest="verbosity")
    opts, rest = parser.parse_args()

    # Build the list of test names.  If names were given on the command
    # line, run exactly those.  Othwerwise build a default list of
    # names.
    if rest:
        names = rest
    else:
        # All Python files starting with 'test' in the current directory
        # and some directories in Extensions contain test cases.
        # FIXME: It should be possible to run runtests.py even when not in
        # the test directory
        names = find_test_modules(test_dir)
    suite = unittest.defaultTestLoader.loadTestsFromNames(names)
    runner = unittest.TextTestRunner(verbosity=opts.verbosity)
    result = runner.run(suite)
    sys.exit(not result.wasSuccessful())


if __name__ == "__main__":
    main()
